@@ -15,7 +15,7 @@
  *
 */
 
-#include "sdf/SDFExtension.hh"
+#include "SDFExtension.hh"
 
 using namespace sdf;
 
@@ -26,6 +26,7 @@ SDFExtension::SDFExtension()
   this->visual_blobs.clear();
   this->collision_blobs.clear();
   this->setStaticFlag = false;
+  this->isGravity = false;
   this->gravity = true;
   this->isDampingFactor = false;
   this->isMaxContacts = false;
@@ -43,9 +44,6 @@ SDFExtension::SDFExtension()
   this->isSpringStiffness = false;
   this->isStopCfm = false;
   this->isStopErp = false;
-  this->isStopKp = false;
-  this->isStopKd = false;
-  this->isInitialJointPosition = false;
   this->isFudgeFactor = false;
   this->isProvideFeedback = false;
   this->isImplicitSpringDamper = false;
@@ -64,9 +62,6 @@ SDFExtension::SDFExtension()
   this->springStiffness = 0;
   this->stopCfm = 0;
   this->stopErp = 0.1;
-  this->stopKp = 100000000;
-  this->stopKd = 1;
-  this->initialJointPosition = 0;
   this->fudgeFactor = 1;
 
   this->provideFeedback = false;
@@ -80,6 +75,7 @@ SDFExtension::SDFExtension(const SDFExtension &_ge)
   this->visual_blobs = _ge.visual_blobs;
   this->collision_blobs = _ge.collision_blobs;
   this->setStaticFlag = _ge.setStaticFlag;
+  this->isGravity = _ge.isGravity;
   this->gravity = _ge.gravity;
   this->isDampingFactor = _ge.isDampingFactor;
   this->isMaxContacts = _ge.isMaxContacts;
@@ -94,11 +90,8 @@ SDFExtension::SDFExtension(const SDFExtension &_ge)
   this->isLaserRetro = _ge.isLaserRetro;
   this->isSpringReference = _ge.isSpringReference;
   this->isSpringStiffness = _ge.isSpringStiffness;
-  this->isStopKp = _ge.isStopKp;
-  this->isStopKd = _ge.isStopKd;
   this->isStopCfm = _ge.isStopCfm;
   this->isStopErp = _ge.isStopErp;
-  this->isInitialJointPosition = _ge.isInitialJointPosition;
   this->isFudgeFactor = _ge.isFudgeFactor;
   this->isProvideFeedback = _ge.isProvideFeedback;
   this->isImplicitSpringDamper = _ge.isImplicitSpringDamper;
@@ -119,10 +112,7 @@ SDFExtension::SDFExtension(const SDFExtension &_ge)
   this->laserRetro = _ge.laserRetro;
   this->springReference = _ge.springReference;
   this->springStiffness = _ge.springStiffness;
-  this->stopKp = _ge.stopKp;
-  this->stopKd = _ge.stopKd;
   this->stopCfm = _ge.stopCfm;
   this->stopErp = _ge.stopErp;
-  this->initialJointPosition = _ge.initialJointPosition;
   this->fudgeFactor = _ge.fudgeFactor;
 }
